@@ -208,10 +208,10 @@ def _get_short_module_name(module_name, obj_name):
 
 # keep in synch w/ configuration.rst "Add mini-galleries for API documentation"
 _regex = re.compile(r':(?:'
-                    r'func(?:tion)?|'
-                    r'meth(?:od)?|'
-                    r'attr(?:ibute)?|'
-                    r'obj(?:ect)?|'
+                    r'func|'
+                    r'meth|'
+                    r'attr|'
+                    r'obj|'
                     r'class):`~?(\S*)`'
                     )
 
@@ -265,7 +265,7 @@ THUMBNAIL_TEMPLATE = """
 .. only:: html
 
   .. image:: /{thumbnail}
-    :alt: {title}
+    :alt:
 
   :ref:`sphx_glr_{ref_name}`
 
