@@ -25,18 +25,23 @@ from sphinx.errors import ConfigError, ExtensionError
 import sphinx.util
 from sphinx.util.console import red
 from . import glr_path_static, __version__ as _sg_version
-from .utils import _replace_md5, _has_optipng, _has_pypandoc
+from .utils import _replace_md5, _has_optipng, _has_pypandoc, _has_graphviz
 from .backreferences import _finalize_backreferences
 from .gen_rst import (generate_dir_rst, SPHX_GLR_SIG, _get_memory_base,
                       _get_readme)
-from .scrapers import _scraper_dict, _reset_dict, _import_matplotlib
+from .scrapers import (
+    _scraper_dict, _reset_dict, _import_matplotlib, _MAYAVI_WARN)
 from .docs_resolv import embed_code_links
 from .downloads import generate_zipfiles
 from .sorting import NumberOfCodeLinesSortKey
-from .binder import copy_binder_files, check_binder_conf
+from .interactive_example import (
+    copy_binder_files, check_binder_conf, check_jupyterlite_conf
+)
+from .interactive_example import pre_configure_jupyterlite_sphinx
+from .interactive_example import post_configure_jupyterlite_sphinx
+from .interactive_example import create_jupyterlite_contents
 from .directives import MiniGallery, ImageSg, imagesg_addnode
 
-
 _KNOWN_CSS = ('sg_gallery', 'sg_gallery-binder', 'sg_gallery-dataframe',
               'sg_gallery-rendered-html')
 
@@ -68,7 +73,7 @@ DEFAULT_GALLERY_CONF = {
     # 'plot_gallery' also accepts strings that evaluate to a bool, e.g. "True",
     # "False", "1", "0" so that they can be easily set via command line
     # switches of sphinx-build
-    'plot_gallery': True,
+    'plot_gallery': 'True',
     'download_all_examples': True,
     'abort_on_example_error': False,
     'only_warn_on_example_error': False,
@@ -80,6 +85,7 @@ DEFAULT_GALLERY_CONF = {
     'thumbnail_size': (400, 280),  # Default CSS does 0.4 scaling (160, 112)
     'min_reported_time': 0,
     'binder': {},
+    'jupyterlite': {},
     'promote_jupyter_magic': False,
     'image_scrapers': ('matplotlib',),
     'compress_images': (),
@@ -102,6 +108,9 @@ DEFAULT_GALLERY_CONF = {
     'line_numbers': False,
     'nested_sections': True,
     'prefer_full_module': [],
+    'api_usage_ignore': '.*__.*__',
+    'show_api_usage': False,  # if this changes, change write_api_entries, too
+    'copyfile_regex': '',
 }
 
 logger = sphinx.util.logging.getLogger('sphinx-gallery')
@@ -150,7 +159,14 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
                            builder_name='html', app=None, check_keys=True):
     gallery_conf = copy.deepcopy(DEFAULT_GALLERY_CONF)
     options = sorted(gallery_conf)
-    extra_keys = sorted(set(sphinx_gallery_conf) - set(options))
+    # sphinx-autoapi can run before our config filling can occur, which
+    # when used with show_api_usage=True can cause us to add this early.
+    # In theory we could bump our priority above theirs, but this could have
+    # unintented consequences.
+    ignore_keys = ('_sg_api_entries',)
+    extra_keys = sorted(
+        (set(sphinx_gallery_conf) - set(options)) - set(ignore_keys)
+    )
     if extra_keys and check_keys:
         msg = 'Unknown key(s) in sphinx_gallery_conf:\n'
         for key in extra_keys:
@@ -232,6 +248,8 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
     for si, scraper in enumerate(scrapers):
         if isinstance(scraper, str):
             if scraper in _scraper_dict:
+                if scraper == 'mayavi':
+                    logger.warning(_MAYAVI_WARN)
                 scraper = _scraper_dict[scraper]
             else:
                 orig_scraper = scraper
@@ -369,6 +387,11 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
     # binder
     gallery_conf['binder'] = check_binder_conf(gallery_conf['binder'])
 
+    # jupyterlite
+    print('_complete_gallery_conf', gallery_conf.get('jupyterlite'))
+    gallery_conf['jupyterlite'] = check_jupyterlite_conf(
+        gallery_conf.get('jupyterlite', {}), app)
+
     if not isinstance(gallery_conf['css'], (list, tuple)):
         raise ConfigError('gallery_conf["css"] must be list or tuple, got %r'
                           % (gallery_conf['css'],))
@@ -379,12 +402,23 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
         if gallery_conf['app'] is not None:  # can be None in testing
             gallery_conf['app'].add_css_file(css + '.css')
 
+    # check API usage
+    if not isinstance(gallery_conf['api_usage_ignore'], str):
+        raise ConfigError('gallery_conf["api_usage_ignore"] must be str, '
+                          'got %s' % type(gallery_conf['api_usage_ignore']))
+
+    if not isinstance(gallery_conf['show_api_usage'], bool) and \
+            gallery_conf['show_api_usage'] != 'unused':
+        raise ConfigError(
+            'gallery_conf["show_api_usage"] must be True, False or "unused", '
+            'got %s' % gallery_conf['show_api_usage'])
+
     _update_gallery_conf(gallery_conf)
 
     return gallery_conf
 
 
-def get_subsections(srcdir, examples_dir, gallery_conf):
+def get_subsections(srcdir, examples_dir, gallery_conf, check_for_index=True):
     """Return the list of subsections of a gallery.
 
     Parameters
@@ -395,6 +429,8 @@ def get_subsections(srcdir, examples_dir, gallery_conf):
         path to the examples directory relative to conf.py
     gallery_conf : dict
         The gallery configuration.
+    check_for_index : bool
+        only return subfolders with a ReadMe, default True
 
     Returns
     -------
@@ -402,9 +438,16 @@ def get_subsections(srcdir, examples_dir, gallery_conf):
         sorted list of gallery subsection folder names
     """
     sortkey = gallery_conf['subsection_order']
-    subfolders = [subfolder for subfolder in os.listdir(examples_dir)
-                  if _get_readme(os.path.join(examples_dir, subfolder),
-                                 gallery_conf, raise_error=False) is not None]
+    subfolders = [subfolder for subfolder in os.listdir(examples_dir)]
+    if check_for_index:
+        subfolders = [subfolder for subfolder in subfolders
+                      if _get_readme(os.path.join(examples_dir, subfolder),
+                                     gallery_conf, raise_error=False)
+                      is not None]
+    else:
+        # just make sure its a directory
+        subfolders = [subfolder for subfolder in subfolders
+                      if os.path.isdir(os.path.join(examples_dir, subfolder))]
     base_examples_dir_path = os.path.relpath(examples_dir, srcdir)
     subfolders_with_path = [os.path.join(base_examples_dir_path, item)
                             for item in subfolders]
@@ -434,6 +477,25 @@ def _prepare_sphx_glr_dirs(gallery_conf, srcdir):
     return list(zip(examples_dirs, gallery_dirs))
 
 
+def _format_toctree(items, includehidden=False):
+    """Format a toc tree"""
+
+    st = """
+.. toctree::
+   :hidden:"""
+    if includehidden:
+        st += """
+   :includehidden:
+"""
+    st += """
+
+   %s\n""" % "\n   ".join(items)
+
+    st += "\n"
+
+    return st
+
+
 def generate_gallery_rst(app):
     """Generate the Main examples gallery reStructuredText
 
@@ -451,13 +513,6 @@ def generate_gallery_rst(app):
     Eventually, we create a toctree in the current index file
     which points to section index files.
     """
-    blocked_builder = ['dirhtml']
-    if app.builder.name in blocked_builder:
-        msg = (
-            f'Builder is set to {repr(app.builder.name)}. sphinx_gallery does '
-            f'not work for any of the following: {[blocked_builder]}'
-        )
-        raise ConfigError(msg)
 
     logger.info('generating gallery...', color='white')
     gallery_conf = parse_config(app)
@@ -475,7 +530,6 @@ def generate_gallery_rst(app):
     check_spaces_in_filenames(files)
 
     for examples_dir, gallery_dir in workdirs:
-
         examples_dir_abs_path = os.path.join(app.builder.srcdir, examples_dir)
         gallery_dir_abs_path = os.path.join(app.builder.srcdir, gallery_dir)
 
@@ -496,49 +550,51 @@ def generate_gallery_rst(app):
             include_toctree=False,
         )
 
+        has_readme = this_content is not None
         costs += this_costs
         write_computation_times(gallery_conf, gallery_dir_abs_path, this_costs)
 
         # We create an index.rst with all examples
         # (this will overwrite the rst file generated by the previous call
         # to generate_dir_rst)
-        index_rst_new = os.path.join(gallery_dir_abs_path, 'index.rst.new')
-        with codecs.open(index_rst_new, 'w', encoding='utf-8') as fhindex:
+
+        if this_content:
             # :orphan: to suppress "not included in TOCTREE" sphinx warnings
-            fhindex.write(":orphan:\n\n" + this_content)
+            indexst = ":orphan:\n\n" + this_content
+        else:
+            # we are not going to use the index.rst.new that gets made here,
+            # but go through the motions to run through all the subsections...
+            indexst = 'Never used!'
 
-            # Write toctree with gallery items from gallery root folder
-            if len(this_toctree_items) > 0:
-                this_toctree = """
-.. toctree::
-   :hidden:
+        # Write toctree with gallery items from gallery root folder
+        if len(this_toctree_items) > 0:
+            this_toctree = _format_toctree(this_toctree_items)
+            indexst += this_toctree
 
-   %s\n
-""" % "\n   ".join(this_toctree_items)
-                fhindex.write(this_toctree)
+        # list all paths to subsection index files in this array
+        subsection_index_files = []
+        subsecs = get_subsections(app.builder.srcdir,
+                                  examples_dir_abs_path, gallery_conf,
+                                  check_for_index=has_readme)
+        for subsection in subsecs:
+            src_dir = os.path.join(examples_dir_abs_path, subsection)
+            target_dir = os.path.join(gallery_dir_abs_path, subsection)
+            subsection_index_files.append(
+                '/'.join([
+                    '', gallery_dir, subsection, 'index.rst'
+                ]).replace(os.sep, '/')  # fwd slashes needed in rst
+            )
 
-            # list all paths to subsection index files in this array
-            subsection_index_files = []
-
-            for subsection in get_subsections(
-                    app.builder.srcdir, examples_dir_abs_path, gallery_conf):
-                src_dir = os.path.join(examples_dir_abs_path, subsection)
-                target_dir = os.path.join(gallery_dir_abs_path, subsection)
-                subsection_index_files.append(
-                    '/'.join([
-                        '', gallery_dir, subsection, 'index.rst'
-                    ])
-                )
-
-                (
-                    subsection_index_path,
-                    subsection_index_content,
-                    subsection_costs,
-                    subsection_toctree_filenames,
-                ) = generate_dir_rst(
-                    src_dir, target_dir, gallery_conf, seen_backrefs
-                )
+            (
+                subsection_index_path,
+                subsection_index_content,
+                subsection_costs,
+                subsection_toctree_filenames,
+            ) = generate_dir_rst(
+                src_dir, target_dir, gallery_conf, seen_backrefs
+            )
 
+            if subsection_index_content:
                 # Filter out tags from subsection content
                 # to prevent tag duplication across the documentation
                 tag_regex = r"^\.\.(\s+)\_(.+)\:(\s*)$"
@@ -547,54 +603,55 @@ def generate_gallery_rst(app):
                     if re.match(tag_regex, line) is None
                 ] + [''])
 
-                fhindex.write(subsection_index_content)
+                indexst += subsection_index_content
+                has_readme_subsection = True
+            else:
+                has_readme_subsection = False
 
-                # Write subsection toctree in main file
-                # only if nested_sections is False or None
-                if not gallery_conf["nested_sections"]:
-                    if len(subsection_toctree_filenames) > 0:
-                        subsection_index_toctree = """
-.. toctree::
-   :hidden:
+            # Write subsection toctree in main file only if
+            # nested_sections is False or None, and
+            # toctree filenames were generated for the subsection.
+            if not gallery_conf["nested_sections"]:
+                if len(subsection_toctree_filenames) > 0:
+                    subsection_index_toctree = _format_toctree(
+                        subsection_toctree_filenames)
+                    indexst += subsection_index_toctree
+            # Otherwise, a new index.rst.new file should
+            # have been created and it needs to be parsed
+            elif has_readme_subsection:
+                _replace_md5(subsection_index_path, mode='t')
 
-   %s\n
-""" % "\n   ".join(subsection_toctree_filenames)
-                    fhindex.write(subsection_index_toctree)
-                # Otherwise, a new index.rst.new file should
-                # have been created and it needs to be parsed
-                else:
-                    _replace_md5(subsection_index_path, mode='t')
+            costs += subsection_costs
+            write_computation_times(
+                gallery_conf, target_dir, subsection_costs
+            )
 
-                costs += subsection_costs
-                write_computation_times(
-                    gallery_conf, target_dir, subsection_costs
-                )
+        # generate toctree with subsections
+        if gallery_conf["nested_sections"] is True:
+            subsections_toctree = _format_toctree(
+                subsection_index_files, includehidden=True)
 
-            # generate toctree with subsections
-            if gallery_conf["nested_sections"] is True:
-                subsections_toctree = """
-.. toctree::
-   :hidden:
-   :includehidden:
+            # add toctree to file only if there are subsections
+            if len(subsection_index_files) > 0:
+                indexst += subsections_toctree
 
-   %s\n
-""" % "\n   ".join(subsection_index_files)
-# """ % "\n   ".join(this_toctree_items + subsection_index_files)
+        if gallery_conf['download_all_examples']:
+            download_fhindex = generate_zipfiles(
+                gallery_dir_abs_path, app.builder.srcdir
+            )
+            indexst += download_fhindex
 
-                # add toctree to file only if there are subsections
-                if len(subsection_index_files) > 0:
-                    fhindex.write(subsections_toctree)
+        if (app.config.sphinx_gallery_conf['show_signature']):
+            indexst += SPHX_GLR_SIG
 
-            if gallery_conf['download_all_examples']:
-                download_fhindex = generate_zipfiles(
-                    gallery_dir_abs_path, app.builder.srcdir
-                )
-                fhindex.write(download_fhindex)
+        if has_readme:
+            index_rst_new = os.path.join(gallery_dir_abs_path, 'index.rst.new')
+            with codecs.open(index_rst_new, 'w', encoding='utf-8') as fhindex:
+                fhindex.write(indexst)
+            _replace_md5(index_rst_new, mode='t')
 
-            if (app.config.sphinx_gallery_conf['show_signature']):
-                fhindex.write(SPHX_GLR_SIG)
-
-        _replace_md5(index_rst_new, mode='t')
+    if gallery_conf['show_api_usage'] is not False:
+        init_api_usage(app.builder.srcdir)
     _finalize_backreferences(seen_backrefs, gallery_conf)
 
     if gallery_conf['plot_gallery']:
@@ -615,11 +672,14 @@ def generate_gallery_rst(app):
         write_junit_xml(gallery_conf, app.builder.outdir, costs)
 
 
-SPHX_GLR_COMP_TIMES = """
+SPHX_GLR_ORPHAN = """
 :orphan:
 
 .. _{0}:
 
+"""
+
+SPHX_GLR_COMP_TIMES = SPHX_GLR_ORPHAN + """
 Computation times
 =================
 """
@@ -688,6 +748,244 @@ def write_computation_times(gallery_conf, target_dir, costs):
             fid.write(hline)
 
 
+def write_api_entries(app, what, name, obj, options, lines):
+    # sphinx-autoapi can do this before we manage to complete our config
+    if 'show_api_usage' not in app.config.sphinx_gallery_conf:
+        app.config.sphinx_gallery_conf['show_api_usage'] = False
+    if app.config.sphinx_gallery_conf['show_api_usage'] is False:
+        return
+    if '_sg_api_entries' not in app.config.sphinx_gallery_conf:
+        app.config.sphinx_gallery_conf['_sg_api_entries'] = dict()
+    if what not in app.config.sphinx_gallery_conf['_sg_api_entries']:
+        app.config.sphinx_gallery_conf['_sg_api_entries'][what] = set()
+    app.config.sphinx_gallery_conf['_sg_api_entries'][what].add(name)
+
+
+def init_api_usage(gallery_dir):
+    with codecs.open(os.path.join(gallery_dir, 'sg_api_usage.rst'), 'w',
+                     encoding='utf-8'):
+        pass
+
+
+def _make_graph(fname, entries, gallery_conf):
+    """Make a graph of unused and used API entries.
+
+    The used API entries themselves are documented in the list, so
+    for the graph, we'll focus on the number of unused API entries
+    per modules. Modules with lots of unused entries (11+) will be colored
+    red, those with less (6+) will be colored orange, those with only a few
+    (1-5) will be colored yellow and those with no unused entries will be
+    colored blue.
+
+    The API entries that are used are shown with one graph per module.
+    That way you can see the examples that each API entry is used in
+    for that module (if this was done for the whole project at once,
+    the graph would get too large very large quickly).
+    """
+    import graphviz
+    dg = graphviz.Digraph(filename=fname,
+                          node_attr={'color': 'lightblue2',
+                                     'style': 'filled',
+                                     'fontsize': '40'})
+
+    if isinstance(entries, list):
+        connections = set()
+        lut = dict()  # look up table for connections so they don't repeat
+        structs = [entry.split('.') for entry in entries]
+        for struct in sorted(structs, key=len):
+            for level in range(len(struct) - 2):
+                if (struct[level], struct[level + 1]) in connections:
+                    continue
+                connections.add((struct[level], struct[level + 1]))
+                node_from = lut[struct[level]] if \
+                    struct[level] in lut else struct[level]
+                dg.attr('node', color='lightblue2')
+                dg.node(node_from)
+                node_to = struct[level + 1]
+                # count, don't show leaves
+                if len(struct) - 3 == level:
+                    leaf_count = 0
+                    for struct2 in structs:
+                        # find structures of the same length as struct
+                        if len(struct2) != level + 3:
+                            continue
+                        # find structures with two entries before
+                        # the leaf that are the same as struct
+                        if all([struct2[level2] == struct[level2]
+                                for level2 in range(level + 2)]):
+                            leaf_count += 1
+                    node_to += f'\n({leaf_count})'
+                    lut[struct[level + 1]] = node_to
+                    if leaf_count > 10:
+                        color = 'red'
+                    elif leaf_count > 5:
+                        color = 'orange'
+                    else:
+                        color = 'yellow'
+                    dg.attr('node', color=color)
+                else:
+                    dg.attr('node', color='lightblue2')
+                dg.node(node_to)
+                dg.edge(node_from, node_to)
+        # add modules with all API entries
+        dg.attr('node', color='lightblue2')
+        for module in gallery_conf['_sg_api_entries']['module']:
+            struct = module.split('.')
+            for i in range(len(struct) - 1):
+                if struct[i + 1] not in lut:
+                    dg.edge(struct[i], struct[i + 1])
+    else:
+        assert isinstance(entries, dict)
+        for entry, refs in entries.items():
+            dg.attr('node', color='lightblue2')
+            dg.node(entry)
+            dg.attr('node', color='yellow')
+            for ref in refs:
+                dg.node(ref)
+                dg.edge(entry, ref)
+
+    dg.attr(overlap='scale')
+    dg.save(fname)
+
+
+def write_api_entry_usage(app, docname, source):
+    """Write an html page describing which API entries are used and unused.
+
+    To document and graph only those API entries that are used by
+    autodoc, we have to wait for autodoc to finish and hook into the
+    ``source-read`` event. This intercepts the text from the rst such
+    that it can be modified. Since, we only touched an empty file,
+    we have to add 1) a list of all the API entries that are unused
+    and a graph of the number of unused API entries per module and 2)
+    a list of API entries that are used in examples, each with a sub-list
+    of which examples that API entry is used in, and a graph that
+    connects all of the API entries in a module to the examples
+    that they are used in.
+    """
+    gallery_conf = app.config.sphinx_gallery_conf
+    if gallery_conf['show_api_usage'] is False:
+        return
+    # since this is done at the gallery directory level (as opposed
+    # to in a gallery directory, e.g. auto_examples), it runs last
+    # which means that all the api entries will be in gallery_conf
+    if 'sg_api_usage' not in docname or \
+            '_sg_api_entries' not in gallery_conf or \
+            gallery_conf['backreferences_dir'] is None:
+        return
+    backreferences_dir = os.path.join(gallery_conf['src_dir'],
+                                      gallery_conf['backreferences_dir'])
+
+    example_files = set.union(
+        *[gallery_conf['_sg_api_entries'][obj_type]
+          for obj_type in ('class', 'method', 'function')
+          if obj_type in gallery_conf['_sg_api_entries']])
+
+    if len(example_files) == 0:
+        return
+
+    def get_entry_type(entry):
+        if entry in gallery_conf['_sg_api_entries'].get('class', []):
+            return 'class'
+        elif entry in gallery_conf['_sg_api_entries'].get('method', []):
+            return 'meth'
+        else:
+            assert entry in gallery_conf['_sg_api_entries']['function']
+            return 'func'
+
+    # find used and unused API entries
+    unused_api_entries = list()
+    used_api_entries = dict()
+    for entry in example_files:
+        # don't include built-in methods etc.
+        if re.match(gallery_conf['api_usage_ignore'], entry) is not None:
+            continue
+        # check if backreferences empty
+        example_fname = os.path.join(
+            backreferences_dir, f'{entry}.examples.new')
+        if not os.path.isfile(example_fname):  # use without new
+            example_fname = os.path.splitext(example_fname)[0]
+        assert os.path.isfile(example_fname)
+        if os.path.getsize(example_fname) == 0:
+            unused_api_entries.append(entry)
+        else:
+            used_api_entries[entry] = list()
+            with open(example_fname, 'r', encoding='utf-8') as fid2:
+                for line in fid2:
+                    if line.startswith('  :ref:'):
+                        example_name = line.split('`')[1]
+                        used_api_entries[entry].append(
+                            example_name)
+
+    source[0] = SPHX_GLR_ORPHAN.format('sphx_glr_sg_api_usage')
+
+    title = 'Unused API Entries'
+    source[0] += title + '\n' + '^' * len(title) + '\n\n'
+    for entry in sorted(unused_api_entries):
+        source[0] += f'- :{get_entry_type(entry)}:`{entry}`\n'
+    source[0] += '\n\n'
+
+    has_graphviz = _has_graphviz()
+    if has_graphviz and unused_api_entries:
+        source[0] += ('.. graphviz:: ./sg_api_unused.dot\n'
+                      '    :alt: API unused entries graph\n'
+                      '    :layout: neato\n\n')
+
+    used_count = len(used_api_entries)
+    total_count = used_count + len(unused_api_entries)
+    used_percentage = used_count / max(total_count, 1)  # avoid div by zero
+    source[0] += ('\nAPI entries used: '
+                  f'{round(used_percentage * 100, 2)}% '
+                  f'({used_count}/{total_count})\n\n')
+
+    if has_graphviz and unused_api_entries:
+        _make_graph(os.path.join(app.builder.srcdir, 'sg_api_unused.dot'),
+                    unused_api_entries, gallery_conf)
+
+    if gallery_conf['show_api_usage'] is True and used_api_entries:
+        title = 'Used API Entries'
+        source[0] += title + '\n' + '^' * len(title) + '\n\n'
+        for entry in sorted(used_api_entries):
+            source[0] += f'- :{get_entry_type(entry)}:`{entry}`\n\n'
+            for ref in used_api_entries[entry]:
+                source[0] += f'  - :ref:`{ref}`\n'
+            source[0] += '\n\n'
+
+        if has_graphviz:
+            used_modules = set([entry.split('.')[0]
+                                for entry in used_api_entries])
+            for module in sorted(used_modules):
+                source[0] += (
+                    f'{module}\n' + '^' * len(module) + '\n\n'
+                    f'.. graphviz:: ./{module}_sg_api_used.dot\n'
+                    f'    :alt: {module} usage graph\n'
+                    '    :layout: neato\n\n')
+
+            for module in used_modules:
+                logger.info(f'Making API usage graph for {module}')
+                # select and format entries for this module
+                entries = dict()
+                for entry, ref in used_api_entries.items():
+                    if entry.split('.')[0] == module:
+                        entry = entry.replace('sphx_glr_', '')
+                        # remove prefix
+                        for target_dir in gallery_conf['gallery_dirs']:
+                            if entry.startswith(target_dir):
+                                entry = entry[len(target_dir) + 1:]
+                _make_graph(os.path.join(app.builder.srcdir,
+                                         f'{module}_sg_api_used.dot'),
+                            entries, gallery_conf)
+
+
+def clean_files(app, exception):
+    if os.path.isfile(os.path.join(app.builder.srcdir, 'sg_api_usage.rst')):
+        os.remove(os.path.join(app.builder.srcdir, 'sg_api_usage.rst'))
+    if os.path.isfile(os.path.join(app.builder.srcdir, 'sg_api_unused.dot')):
+        os.remove(os.path.join(app.builder.srcdir, 'sg_api_unused.dot'))
+    for file in os.listdir(app.builder.srcdir):
+        if 'sg_api_used.dot' in file:
+            os.remove(os.path.join(app.builder.srcdir, file))
+
+
 def write_junit_xml(gallery_conf, target_dir, costs):
     if not gallery_conf['junit'] or not gallery_conf['plot_gallery']:
         return
@@ -908,8 +1206,19 @@ def setup(app):
     for key in ['plot_gallery', 'abort_on_example_error']:
         app.add_config_value(key, get_default_config_value(key), 'html')
 
+    # set small priority value, so that pre_configure_jupyterlite_sphinx is
+    # called before jupyterlite_sphinx config-inited
+    app.connect(
+        'config-inited', pre_configure_jupyterlite_sphinx, priority=100)
+    # set high priority value, so that post_configure_jupyterlite_sphinx is
+    # called after jupyterlite_sphinx config-inited
+    app.connect(
+        'config-inited', post_configure_jupyterlite_sphinx, priority=900)
+
     if 'sphinx.ext.autodoc' in app.extensions:
         app.connect('autodoc-process-docstring', touch_empty_backreferences)
+        app.connect('autodoc-process-docstring', write_api_entries)
+        app.connect('source-read', write_api_entry_usage)
 
     # Add the custom directive
     app.add_directive('minigallery', MiniGallery)
@@ -919,8 +1228,11 @@ def setup(app):
 
     app.connect('builder-inited', generate_gallery_rst)
     app.connect('build-finished', copy_binder_files)
+    app.connect('build-finished', create_jupyterlite_contents)
+
     app.connect('build-finished', summarize_failing_examples)
     app.connect('build-finished', embed_code_links)
+    app.connect('build-finished', clean_files)
     metadata = {'parallel_read_safe': True,
                 'parallel_write_safe': True,
                 'version': _sg_version}
